==> haskell-hslua-list-1.1.3-66-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-list.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-list
version:              1.1.3
visibility:           public
id:                   hslua-list-1.1.3-HxUW8TWoAA17ty5MUZkzyK
key:                  hslua-list-1.1.3-HxUW8TWoAA17ty5MUZkzyK
license:              MIT
copyright:            © 2022-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Opinionated, but extensible Lua list type.
description:          List type for Lua, with a Haskell interface.
category:             Foreign
abi:                  48235bff08d6641fbbe42590862ccc1a
exposed:              True
exposed-modules:      HsLua.List
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-list-1.1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-list-1.1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-list-1.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-list
hs-libraries:         HShslua-list-1.1.3-HxUW8TWoAA17ty5MUZkzyK
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    hslua-core-2.3.1-AjXmog4MFatCGSrMzVuVPQ

haddock-interfaces:   /usr/share/doc/haskell-hslua-list/html/hslua-list.haddock
haddock-html:         /usr/share/doc/haskell-hslua-list/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-list-1.1.3-67-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-list.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-list
version:              1.1.3
visibility:           public
id:                   hslua-list-1.1.3-JJGeN0t8hCZFo2HrVT3BN
key:                  hslua-list-1.1.3-JJGeN0t8hCZFo2HrVT3BN
license:              MIT
copyright:            © 2022-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Opinionated, but extensible Lua list type.
description:          List type for Lua, with a Haskell interface.
category:             Foreign
abi:                  1eb13790b43aee47f685c7f49d8a19f1
exposed:              True
exposed-modules:      HsLua.List
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-list-1.1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-list-1.1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-list-1.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-list
hs-libraries:         HShslua-list-1.1.3-JJGeN0t8hCZFo2HrVT3BN
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    hslua-core-2.3.1-8UKtW8ALUvCDY9LUMLjR8F

haddock-interfaces:   /usr/share/doc/haskell-hslua-list/html/hslua-list.haddock
haddock-html:         /usr/share/doc/haskell-hslua-list/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
